==> django-compress-storage-0.7.8.zip: django-compress-storage-0.7.8/compress_storage/base.py <==
# -*- coding: utf-8 -*-
try:
    from celery.task import task
except ImportError:
    task = None

import os
from django.conf import settings
from django.db.models.fields.files import FieldFile

FILE_COMPRESS_DELETE_OLD_FILE = getattr(settings, 'FILE_COMPRESS_DELETE_OLD_FILE', True)


class CompressFieldFile(FieldFile):
    compress_ext = None

    def _is_compressed(self):
        basename, ext = os.path.splitext(self.name)
        compress_ext = '.' + self.compress_ext
        return compress_ext == ext
    is_compressed = property(_is_compressed)

    def _base_name(self):
        return os.path.basename(self.file.name)
    base_name = property(_base_name)

    def _compress_name(self):
        basename, ext = os.path.splitext(self.name)
        return basename + ('.' + self.compress_ext)
    compress_name = property(_compress_name)

    def _compress_full_name(self):
        basename, ext = os.path.splitext(self.file.name)
        return basename + ('.' + self.compress_ext)
    compress_full_name = property(_compress_full_name)

    def compress_content(self):
        """
        Method to change for new implementations
        """
        raise NotImplementedError()

    def _update_filefield_name(self, delete_old_file=True):
        # update field value
        old_name = self.name

        setattr(self.instance, self.field.name, self.compress_name)
        self.instance.save()

        if delete_old_file:
            self.file.close()
            self.storage.delete(old_name)

    def compress_wrapper(self, delete_old_file=True):
        self.compress_content()
        self._update_filefield_name(delete_old_file=delete_old_file)

    def compress(self, async=True, delete_old_file=FILE_COMPRESS_DELETE_OLD_FILE):
        if self.is_compressed:
            return u'This file is alredy compress'

        if async and task:
            wrapper = task(self.compress_wrapper).delay(delete_old_file=delete_old_file)
        else:
            wrapper = self.compress_wrapper(delete_old_file=delete_old_file)

        return wrapper

==> django-compress-storage-0.7.9.zip: django-compress-storage-0.7.9/compress_storage/base.py <==
# -*- coding: utf-8 -*-
try:
    from celery.task import task
except ImportError:
    task = None

import os
from django.conf import settings
from django.db.models.fields.files import FieldFile

FILE_COMPRESS_DELETE_OLD_FILE = getattr(settings, 'FILE_COMPRESS_DELETE_OLD_FILE', True)


class CompressFieldFile(FieldFile):
    compress_ext = None

    def _is_compressed(self):
        basename, ext = os.path.splitext(self.name)
        compress_ext = '.' + self.compress_ext
        return compress_ext == ext
    is_compressed = property(_is_compressed)

    def _base_name(self):
        return os.path.basename(self.file.name)
    base_name = property(_base_name)

    def _compress_name(self):
        basename, ext = os.path.splitext(self.name)
        return basename + ('.' + self.compress_ext)
    compress_name = property(_compress_name)

    def _compress_full_name(self):
        basename, ext = os.path.splitext(self.file.name)
        return basename + ('.' + self.compress_ext)
    compress_full_name = property(_compress_full_name)

    def compress_content(self):
        """
        Method to change for new implementations
        """
        raise NotImplementedError()

    def _update_filefield_name(self, delete_old_file=True):
        # update field value
        old_name = self.name

        setattr(self.instance, self.field.name, self.compress_name)
        self.instance.save()

        if delete_old_file:
            self.file.close()
            self.storage.delete(old_name)

    def compress_wrapper(self, delete_old_file):
        self.compress_content()
        self._update_filefield_name(delete_old_file=delete_old_file)
        return True

    def compress(self, async=True, delete_old_file=FILE_COMPRESS_DELETE_OLD_FILE):
        if self.is_compressed:
            return u'This file is alredy compress'

        if async and task:
            from .tasks import task_compress_wrapper
            wrapper = task_compress_wrapper.delay(self.instance, self.field.name, delete_old_file)
        else:
            wrapper = CompressFieldFile.compress_wrapper(self, delete_old_file)

        return wrapper
